@@ -13,8 +13,8 @@ def getOptionVal(options, key):
 
 def main():
     try:
-        opts, args = getopt.gnu_getopt(sys.argv[1:], 'm:hvi:c:s', [
-            'mode=', 'help', 'version', 'img_service=', 'change_token=', 'scan', 'des_dir='])
+        opts, args = getopt.gnu_getopt(sys.argv[1:], 'm:hvi:c:su:', [
+            'mode=', 'help', 'version', 'img_service=', 'change_token=', 'scan', 'des_dir=','url_encode='])
     except getopt.GetoptError as e:
         print("获取参数信息出错，错误提示：", e.msg)
         exit()
@@ -50,6 +50,9 @@ def main():
                     mainProcess.changeToken(argVal)
             elif argKey == '--scan' or argKey == '-s':
                 mainProcess.scanAndCreateIndex()
+            elif argKey == '--url_encode' or argKey == '-u':
+                params = {'use_url_encode':argVal}
+                mainProcess.changeMainPrams(params)
             else:
                 mainProcess.main()
             break
